@@ -15,7 +15,7 @@
 #define QT_FEATURE_posix_fallocate 1
 #define QT_FEATURE_reduce_exports 1
 #define QT_FEATURE_reduce_relocations -1
-#define QT_FEATURE_release_tools 1
+#define QT_FEATURE_release_tools -1
 #define QT_FEATURE_relocatable 1
 #define QT_FEATURE_sql 1
 #define QT_FEATURE_stack_protector_strong -1
